import { ProjectHookSchema } from "@gitbeaker/rest"

import GitlabBaseService from "./base"

class Hook extends GitlabBaseService {
  /**
   * 为特定项目检索 GitLab Web 钩子。
   * @returns {Promise<ProjectHookSchema[]>}
   */
  async getList() {
    const URL = `/projects/${this.project_id}/hooks`
    return this.errorWarp<ProjectHookSchema[]>(() => this.get(URL), [])
  }

  /**
   * 添加 GitLab Web 钩子。
   * @param {Partial<ProjectHookSchema>} hook 钩子配置
   * @returns {Promise<ProjectHookSchema | null>}
   */
  async add(hook: Partial<ProjectHookSchema>) {
    const URL = `/projects/${this.project_id}/hooks`
    return this.errorWarp<ProjectHookSchema | null>(
      () => this.post(URL, hook),
      null
    )
  }

  /**
   * 删除 GitLab Web 钩子。
   * @param {number} hookId 钩子 ID
   * @returns {Promise<ProjectHookSchema | null>}
   */
  async delete(hookId: number) {
    const URL = `/projects/${this.project_id}/hooks/${hookId}`
    return this.errorWarp<ProjectHookSchema | null>(() => this.del(URL), null)
  }
}

export default Hook
